==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/assignment.php <==
<?PHP // $Id: assignment.php,v 1.16 2004/03/24 15:04:59 paca70 Exp $ 
      // assignment.php - created with Moodle 1.2 Beta +++ (2004031300)


$string['allowresubmit'] = 'Salli uudelleenlhetys';
$string['assignmentdetails'] = 'Tehtvn tiedot';
$string['assignmentmail'] = '$a->teacher on lhettnyt sinulle palautetta tehtvst \'$a->assignment\'

Voit nhd sen osoitteessa:

$a->url
';
$string['assignmentmailhtml'] = '$a->teacher on lhettnyt sinulle palautetta tehtvst \'<i>$a->assignment</i>\'<br /><br />

Voit nhd sen osoitteessa:

<a href=\"$a->url\">Tehtvn palautus</a>.';
$string['assignmentname'] = 'Tehtvn nimi';
$string['assignmenttype'] = 'Tehtvn tyyppi';
$string['configmaxbytes'] = 'Oletusasetus tehtvn maksimikoolle kaikille tehtville sivustolla';
$string['description'] = 'Kuvaus';
$string['duedate'] = 'Palautuspivmr';
$string['duedateno'] = 'Ei palautuspivmr';
$string['early'] = '$a ajoissa';
$string['existingfiledeleted'] = 'Tiedosto on poistettu: $a';
$string['failedupdatefeedback'] = 'Palautteen tallentaminen eponnistui kyttjlle $a';
$string['feedback'] = 'Palaute';
$string['feedbackupdated'] = 'Vastausten palautteet pivitetty $a oppilaalle';
$string['late'] = '$a myhss';
$string['maximumgrade'] = 'Arvosanan ylraja';
$string['maximumsize'] = 'Maksimikoko';
$string['modulename'] = 'Tehtv';
$string['modulenameplural'] = 'Tehtvt';
$string['newsubmissions'] = 'Palautetut tehtvt';
$string['notgradedyet'] = 'Ei viel arvioitu';
$string['notsubmittedyet'] = 'Ei viel palautettu';
$string['overwritewarning'] = 'Varoitus: uudelleen lhettminen KORVAA aiemman vastauksesi';
$string['saveallfeedback'] = 'Tallenna palaute';
$string['submissionfeedback'] = 'Palaute tehtvst';
$string['submissions'] = 'Palautukset';
$string['submitassignment'] = 'Palauta tehtvsi kytten tt lomaketta';
$string['submitted'] = 'Palautettu';
$string['typeoffline'] = 'Offline-tehtv';
$string['typeuploadsingle'] = 'Lhet yksi tiedosto';
$string['uploadbadname'] = 'Tiedostonimess on tuntemattomia merkkej. Tiedostoa ei voida lhett.';
$string['uploadedfiles'] = 'lhetetyt tiedostot';
$string['uploaderror'] = 'Tiedoston tallentamisessa palvelimelle tapahtui virhe.';
$string['uploadfailnoupdate'] = 'Tiedosto saapui palvelimelle, mutta vastauksesi tallentamisessa tapahtui virhe.';
$string['uploadfiletoobig'] = 'Valitettavasti tiedosto, jota yritit lhett, on liian suuri (kokorajoitus on $a tavua).';
$string['uploadnofilefound'] = 'Tiedostoa ei lydy - oletko varma, ett valitsit tiedoston lhetettvksi?';
$string['uploadnotregistered'] = '\'$a\' vastaanotettiin, mutta lhetystsi ei rekisterity. ';
$string['uploadsuccess'] = '\'$a\' on vastaanotettu palvelimelle.';
$string['viewfeedback'] = 'Katso tehtvien arviointeja ja palautteita.';
$string['viewsubmissions'] = 'Katso palautettuja tehtvi, joiden lukumr on $a';
$string['yoursubmission'] = 'Vastauksesi';

?>

==> moodle_1.5.2.orig.tar.gz: moodle/lang/fi/assignment.php <==
<?PHP // $Id$ 
      // assignment.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004112900)


$string['allowresubmit'] = 'Salli uudelleenpalautus';
$string['assignmentdetails'] = 'Tehtvn tiedot';
$string['assignmentmail'] = '$a->teacher on antanut sinulle palautetta tehtvst \'$a->assignment\'

Voit nhd sen osoitteessa:

$a->url';
$string['assignmentmailhtml'] = '$a->teacher on antanut sinulle palautetta tehtvst \'<i>$a->assignment</i>\'<br /><br />

Voit nhd sen osoitteessa:

<a href=\"$a->url\">Tehtvn palautus</a>.';
$string['assignmentname'] = 'Tehtvn nimi';
$string['assignmenttype'] = 'Tehtvn tyyppi';
$string['configmaxbytes'] = 'Oletusasetus sivuston tehtvien maksimikoolle.';
$string['description'] = 'Kuvaus';
$string['duedate'] = 'Palautettava viimeistn';
$string['duedateno'] = 'Ei palautuspivmr';
$string['early'] = '$a ajoissa';
$string['existingfiledeleted'] = 'Tiedosto on poistettu: $a';
$string['failedupdatefeedback'] = 'Palautteen tallentaminen kyttjlle $a eponnistui';
$string['feedback'] = 'Palaute';
$string['feedbackupdated'] = 'Vastausten palautteet pivitetty $a oppilaalle';
$string['late'] = '$a myhss';
$string['maximumgrade'] = 'Arvosanan ylraja';
$string['maximumsize'] = 'Maksimikoko';
$string['modulename'] = 'Tehtv';
$string['modulenameplural'] = 'Tehtvt';
$string['newsubmissions'] = 'Palautetut tehtvt';
$string['notgradedyet'] = 'Ei viel arvioitu';
$string['notsubmittedyet'] = 'Ei viel palautettu';
$string['overwritewarning'] = 'Varoitus: uudelleen lhettminen KORVAA aiemman vastauksesi.';
$string['saveallfeedback'] = 'Tallenna palaute';
$string['submissionfeedback'] = 'Palaute tehtvst';
$string['submissions'] = 'Palautukset';
$string['submitassignment'] = 'Palauta tehtvsi kytten tt lomaketta';
$string['submitted'] = 'Palautettu';
$string['typeoffline'] = 'Offline-tehtv';
$string['typeuploadsingle'] = 'Lhet yksi tiedosto';
$string['uploadbadname'] = 'Tiedostonimess on tuntemattomia merkkej. Tiedostoa ei voida lhett.';
$string['uploadedfiles'] = 'lhetetyt tiedostot';
$string['uploaderror'] = 'Tiedoston tallentamisessa palvelimelle tapahtui virhe.';
$string['uploadfailnoupdate'] = 'Tiedosto saapui palvelimelle, mutta vastauksesi tallentamisessa tapahtui virhe.';
$string['uploadfiletoobig'] = 'Valitettavasti tiedosto, jota yritit lhett, on liian suuri (kokorajoitus on $a tavua).';
$string['uploadnofilefound'] = 'Tiedostoa ei lydy - oletko varma, ett valitsit tiedoston lhetettvksi?';
$string['uploadnotregistered'] = '\'$a\' vastaanotettiin, mutta lhetystsi ei rekisterity. ';
$string['uploadsuccess'] = '\'$a\' on vastaanotettu palvelimelle.';
$string['viewfeedback'] = 'Katso tehtvien arviointeja ja palautteita.';
$string['viewsubmissions'] = 'Katso palautettuja tehtvi, joiden lukumr on $a';
$string['yoursubmission'] = 'Vastauksesi';

?>
